__version__ = "0.4.1"
__git_commiter_name__ = "Tal Yalon"
__git_commiter_email__ = "tal.yalon@gmail.com"
__git_branch__ = '(detached from v0.4.1)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = '412417c4ccd136f895a0543ff27e5743d498b071'
__git_head_subject__ = 'optional title in request_id_tag context'
__git_head_message__ = ''
__git_dirty_diff__ = ''


import logbook


def redirect_python_logging_to_logbook():
    """
    Safely redirects Python's stdandard library logging to logbook. Unlike logbook.compat.redirect_logging,
    this method can be called multiple times in the same process or logbook context.
    """
    # When we run nose tests we want to the opposite - redirect logbook to logging so nose will capture it.
    # So we shound't redirect back in this case otherwise we'll cause an infinite recursion loop.
    from logbook.compat import redirect_logging, LoggingHandler
    if not any(isinstance(obj, LoggingHandler) for obj in logbook.default_handler.stack_manager.iter_context_objects()):
        redirect_logging()
